@@ -6,7 +6,7 @@ IMG_CLASSIFY = [['模特图', '模特上身图', '模特上身正面'], ['模特
                 ['模特图', '模特全身图', '模特全身正面'], ['模特图', '模特全身图', '模特全身侧面'], ['模特图', '模特全身图', '模特全身背面'],
                 ['细节图', '面料'], ['细节图', '领部'], ['细节图', '肩部'], ['细节图', '腰部'], ['细节图', '衣袖'], ['细节图', '下摆'],
                 ['细节图', '口袋'], ['细节图', '门襟'], ['细节图', '内衬'], ['细节图', '图案'], ['细节图', '裤脚'],
-                ['平铺图', '平铺图背面'], ['平铺图', '平铺图正面'],
+                ['平铺图', '平铺图背面'], ['平铺图', '平铺图正面'], ['平铺图', '平铺图侧面'],
                 ['资质图', '吊牌图'], ['资质图', '洗水唛'],
                 ['动图']
                 ]
@@ -16,7 +16,7 @@ CROP_TYPE = {
     'm_bu': ['模特胸像正面', '模特胸像侧面', '模特胸像背面'],
     'm_bo': ['模特下身正面', '模特下身侧面', '模特下身背面'],
     'm_f': ['模特全身正面', '模特全身侧面', '模特全身背面'],
-    't': ['平铺图背面', '平铺图正面'],
+    't': ['平铺图背面', '平铺图正面', '平铺图侧面'],
     'b': ['资质图', '吊牌图', '洗水唛'],
     'g': ['动图'],
 }
