@@ -166,15 +166,15 @@ class ImageCrop:
         if denominator == 0:
             return default
 
-        return numerator/denominator
+        return numerator / denominator
 
     def crop(self, slot_config, img):
         """
         需求文档： https://www.teambition.com/task/619e01f619f251003f289802
         """
 
-        if slot_config[DATA_SLOT_ID] == '3e1ba404-0710-4e2b-88b3-eae7ef2faa7b' and 'a1' in img.filename:
-            print(img.image_classification_list, img.filename)
+        # if slot_config[DATA_SLOT_ID] == '3e1ba404-0710-4e2b-88b3-eae7ef2faa7b' and 'a1' in img.filename:
+        #     print(img.image_classification_list, img.filename)
 
         slot_width = slot_config.get('width')
         slot_height = slot_config.get('height')
@@ -237,6 +237,9 @@ class ImageCrop:
         y1 = max(top - padding_top, 0)
         y2 = min(bottom + padding_bottom, 1)
 
+        expand_y1 = top - padding_top
+        expand_y2 = bottom + padding_bottom
+
         self.si.get_top_and_bottom_padding(top, padding_top, bottom, padding_bottom)
 
         # 兴趣区域裁剪
@@ -265,8 +268,9 @@ class ImageCrop:
 
             x_center = left + (right - left) / 2  # x 轴的居中
             if transform_img_width >= slot_width and transform_img_height >= slot_height \
-                    and y1*img.height*height_scale >= interest_top \
-                    and (1-y2)*img.height*height_scale >= slot_height-interest_top-interest_height:  # 槽的上下左右都能被满足
+                    and y1 * img.height * height_scale >= interest_top \
+                    and (
+                    1 - y2) * img.height * height_scale >= slot_height - interest_top - interest_height:  # 槽的上下左右都能被满足
                 scale_x = scale_y = height_scale
                 y = max(0, (y1 * img.height - interest_top / scale_x) / img.height)
                 x = self._alternative_interest_center(x_center, slot_width, transform_img_width, interest_left,
@@ -274,8 +278,8 @@ class ImageCrop:
 
                 self.si.top_and_bottom_crop_result(True)  # 上下裁剪点都存在
 
-            elif transform_img_height >= slot_height and y1*img.height*height_scale >= interest_top \
-                    and (1-y2)*img.height*height_scale >= slot_height-interest_top-interest_height \
+            elif transform_img_height >= slot_height and y1 * img.height * height_scale >= interest_top \
+                    and (1 - y2) * img.height * height_scale >= slot_height - interest_top - interest_height \
                     and transform_img_width < slot_width:
                 width_scale = slot_width / img.width
                 x = 0
@@ -291,7 +295,8 @@ class ImageCrop:
 
                     if left == 0.5 and right == 0.5:  # 图片能放在slot位内 human 会被裁掉
                         min_img_left_ratio = self.__divide(interest_left + interest_width / 2, 0.5 * img.width)
-                        min_img_right_ratio = self.__divide(slot_width-interest_left-interest_width/2, 0.5 * img.width)
+                        min_img_right_ratio = self.__divide(slot_width - interest_left - interest_width / 2,
+                                                            0.5 * img.width)
 
                         max_ratio = max(min_top_ratio, min_bottom_ratio, min_img_left_ratio, min_img_right_ratio)
                         # 换算 回 原图的x
@@ -300,7 +305,8 @@ class ImageCrop:
                     else:  # human 放在 兴趣区域内
                         min_human_left_ratio = self.__divide(interest_left + interest_width / 2, x_center * img.width)
 
-                        min_human_right_ratio = self.__divide(slot_width-interest_left-interest_width/2, (1 - x_center)*img.width)
+                        min_human_right_ratio = self.__divide(slot_width - interest_left - interest_width / 2,
+                                                              (1 - x_center) * img.width)
 
                         max_ratio = max(min_top_ratio, min_bottom_ratio, min_human_left_ratio, min_human_right_ratio)
 
@@ -413,7 +419,7 @@ class ImageCrop:
             self.si.top_and_bottom_crop_result(True)  # 上下裁剪点都存在
         elif crop_method == 'e':  # 扩边裁剪，slot高不变,宽可以改变
             crop_x, crop_y, crop_width, crop_height, scale_x, scale_y, amend_layout_height = self.__extension_crop(
-                y1, y2, {'x1': x1, 'x2': x2}, [slot_width, slot_height], img
+                expand_y1, expand_y2, {'x1': x1, 'x2': x2}, [slot_width, slot_height], img
             )
 
         else:  # 固定裁剪, slot宽高不变
